<!-- cspell:ignore madr -->

# Architectural Decision Records

This log lists the architectural decisions for the
[ExpertSystem repository](https://github.com/ComPWA/expertsystem):

```{toctree}
---
glob:
maxdepth: 1
---
adr/*
```

For new ADRs, please use {download}`adr/template.md` as basis. This template
was inspired by [MADR](https://adr.github.io/madr). General information about
architectural decision records is available at
[adr.github.io](https://adr.github.io).
